<?php
// $Id$

/**
 * @file
 * OM Maximenu Admin Utilities
 *
 * @author: Daniel Honrade http://drupal.org/user/351112
 *
 */

drupal_add_js(drupal_get_path('module', 'om_maximenu') . '/js/om_maximenu.js', 'module'); 
     
/**
 * Load all OM Maximenu blocks
 * 
 * This will process all created OM Maximenu blocks
 *
 */
function om_maximenu_load($maximenu_delta = '') {
  static $once = 0;
  $maximenu_delta = explode('-', $maximenu_delta);
  //$maximenu_delta = 'om-maximenu-1';
  $delta = $maximenu_delta[2];
  if ($delta != 0) {
    $menus = array();
    $maximenus = variable_get('om_maximenu', $menus);
    if (!empty($maximenus)) {
    $skin = $maximenus[$delta]['skin'];
    $fade = $maximenus[$delta]['fade'];    
    $maximenus[$delta]['skin'] = $skin;
    $maximenu_name = strtolower(preg_replace('/ /', '-', $maximenus[$delta]['title']));      
    drupal_add_css(drupal_get_path('module', 'om_maximenu') . '/skin/' . $skin . '/' . $skin . '.css');
    om_maximenu_hover_js($fade, 'om-maximenu-' . $maximenu_name);
    $out = array();
    $out['title'] = $maximenus[$delta]['title'];
    $out['content'] = om_maximenu_links_render($maximenus[$delta]);
    $once++;
    return $out;
    }
  }
}


/**
 * OM Maximenu links rendering engine
 *
 */
function om_maximenu_links_render($links = array()) {
  if (!isset($links['links'])) return NULL;
  global $user;
  //dsm($user);
  $user_id = $user->uid;  
  $user_roles = $user->roles;
  $count = 0;
  $total = count($links);
  $skin = preg_replace('/_/', '-', $links['skin']);
  $maximenu_name = strtolower(preg_replace('/ /', '-', $links['title']));      
  $out = '<div class="om-maximenu om-maximenu-' . $skin . ' om-maximenu-' . $maximenu_name . '">';
  $out .= '<ul class="om-menu">';  

  usort($links['links'], 'om_sort_by_weight'); 
  $attributes = array();
  foreach ($links['links'] as $key => $content) {
    // user permission to view the link
    // roles
    // 1 - anonymous
    // 2 - authenticated
    //dsm($content['roles']);
    $roles = $content['roles'];
    $permission = array();
    $anyone = 0;
    foreach ($roles as $role => $value) {
       // check roles
       if (($value != 0) && isset($user_roles[$role])) $permission[$role] = $user_roles[$role];
       // for all roles are unchecked
       if ($value != 0) $anyone++;       
    }
    // the link will be visible if the user has permission or
    // the links is for everybody or
    // the user is a super user
    if (!empty($permission) || ($anyone == 0) || ($user_id == 1)) {    
      $count++;
      //dsm($content);
      $class_id = preg_replace('/ /', '-', strtolower($content['link_title']));
      
      $link_title_option = $content['link_title_option'];
      $link_title = $content['link_title'];      
      $link_icon = !empty($content['path_icon']) ? '<img src="' . base_path() . $content['path_icon'] . '" alt="' . $link_title . '" />': '';

      if ($link_title_option == 'title_icon') {
        $link_option = $link_icon . ' ' . $link_title;
      }
      elseif ($link_title_option == 'icon') {
        $link_option = $link_icon;
      }
      else {
        $link_option = $link_title;
      }
                        
      // li classes
      ($count == 1) ? $classes = ' first': $classes = '';
      if ($count == $total) $classes .= ' last';  
      $classes .= ' leaf-' . $class_id;     
      if ($_GET['q'] == $content['path']) $classes .= ' active'; 
      if (empty($content['path']) && drupal_is_front_page()) {
        $classes .= ' active'; 
        $content['class'] .= ' active'; 
      }  
      // user role class
      foreach ($permission as $pkey => $pval) {
        $pval = strtolower(preg_replace('/ /', '-', $pval));
        $classes .= ' leaf-role-' . $pval; 
      }        
      // link attributes
      if (!empty($content['id'])) {
        $attributes['id'] = $content['id'];
        $span_id = 'id="' . $content['id'] . '"';        
      }
            
      $attributes['class'] = 'om-link ' . $content['class'] . ' link-' . $class_id;
      if (!empty($content['description'])) {
        $attributes['title'] = $content['description']; 
        $span_title = 'title="' . $content['description'] . '"'; 
      }    
      
      if (!empty($content['rel'])) $attributes['rel'] = $content['rel'];
      if (!empty($content['target']) && ($content['target'] != '_self')) $attributes['target'] = $content['target'];
            
      $out .= '<li id="om-leaf-' . $key . '" class="om-leaf' . $classes . '">';    
      if (!empty($content['path'])) {
        // Drupal doesn't accept # as valid path
        //$out .= l($content['link_title'], $content['path'], array('attributes' => $attributes));
        $path = ($content['path'] == '<front>') ? '': $content['path'];
        $out .= '<a ' . drupal_attributes($attributes) . ' href="' . base_path() . $path . '">' . $link_option . '</a>';
      }
      else {
        // useful when you just want a button for getting the content to show and not actually linking to anything
        $out .= '<span ' . $span_id . ' class="' . $attributes['class']. '" ' . $span_title . '>' . $link_option . '</span>';
      }
      
      $out .= om_maximenu_content_render($content['content']);    
      $out .= '</li>';
    }
  }
  $out .= '</ul>';  
  if (user_access('administer OM Maximenu')) $out .= '<div class="om-maximenu-edit"><a href="' . base_path() . 'admin/settings/om-maximenu?destination=' . $_GET['q']. '">Edit Maximenu</a></div>';    
  $out .= '</div>';  
  return $out;
}


/**
 * OM Maximenu content rendering engine
 *
 */
function om_maximenu_content_render($content = '') {

  if (!empty($content)) {
    // enclose the content with divs for efficient image border theming
    $out = '<div class="om-maximenu-content om-maximenu-content-nofade">';
    $out .= '<div class="om-maximenu-top"><div class="om-maximenu-top-left"></div><div class="om-maximenu-top-right"></div></div>';
    $out .= '<div class="om-maximenu-middle"><div class="om-maximenu-middle-left"><div class="om-maximenu-middle-right">';      
    $count = 0;
    usort($content, 'om_sort_by_weight');  
    foreach ($content as $key => $prop) {
        $count++;
        ($count == 1) ? $classes = ' first': $classes = '';
        if ($count == $total) $classes .= ' last'; 
        $path = ($prop['title_path'] == '<front>') ? '': $prop['title_path'];
        $block_title = (!empty($prop['title_path'])) ? '<a href="' . base_path() . $path .'" title="' . $prop['title'] . '">' . $prop['title'] . '</a>': $prop['title'];      
        $block = module_invoke($prop['module'], 'block', 'view', $prop['delta']); 
        $out .= '<div class="block block-' . $prop['module'] . ' block-' . $prop['module'] . '-id-' . $prop['delta'] . $classes . '">';            
        $out .= ($prop['title'] != '<none>') ? '<h3 class="title">' . $block_title . '</h3>': ''; 
        $out .= $block['content']; 
        $out .= '</div>';            
    }
    $out .= '<div class="clearfix"></div></div></div></div>';      
    $out .= '<div class="om-maximenu-bottom"><div class="om-maximenu-bottom-left"></div><div class="om-maximenu-bottom-right"></div></div>';    
    $out .= '<div class="om-maximenu-arrow"></div>';    
    $out .= '</div>'; 
    return $out;
  } 
}

/**
 * Sorting by weight
 *
 */
function om_sort_by_weight($a, $b) {
  return $a['weight'] - $b['weight'];
}


/**
 * OM Maximenu get styles from /skin directory
 * - reads directory names
 */
function om_maximenu_style_get() {
  $files = array();
  $dir = drupal_get_path('module', 'om_maximenu') . '/skin/';
  $folders = scandir($dir);
  $excluded_files = array('.', '..', '.cvs', '.svn', '.git');

  foreach ($folders as $key => $val) {
		if (!in_array($val, $excluded_files)) (is_dir($dir . $val)) ? $files[$val] = ucwords(preg_replace('/_/', ' ', $val)): '';     
  }
  return $files;
}


/**
 * Hover delay using hoverintent jquery plugin
 *
 */
function om_maximenu_hover_js($checked = 0, $menu = 'om-maximenu') {
  
  $add_js = "
    $(document).ready(function(){
      $('." . $menu . " li.om-leaf .om-maximenu-content').removeClass('om-maximenu-content-nofade');
      //$('." . $menu . " li.om-leaf').hover(omFadeIn,omFadeOut); //native jquery
      //$('." . $menu . " li.om-leaf').hoverIntent(omFadeIn,omFadeOut); //jquery hoverintent
      $('." . $menu . " li.om-leaf').hoverIntent({
        over: omFadeIn,
        timeout: 500,
        out: omFadeOut
      });
    });
    function omFadeIn(){ $('.om-maximenu-content', this).fadeIn();}
    function omFadeOut(){ $('.om-maximenu-content', this).fadeOut();} 
    ";
  if ($checked == 1) {
    drupal_add_js(drupal_get_path('module', 'om_maximenu') . '/contrib/jquery.hoverIntent.minified.js', 'module'); 
    drupal_add_js($add_js, "inline");
  }
}


